@@ -1,7 +1,6 @@
-#!/usr/bin/python
 #-*- coding: utf-8 -*-
 
-# Copyright 2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -201,7 +200,8 @@ class CertClass (QtGui.QWidget):
         cert_path = self.default_cert_path
         if not os.path.exists(cert_path + 'req_id'):
             show_msg (_("Request not sent, or file %s deleted") \
-                                                %(cert_path + 'req_id'), self)
+                                                %(cert_path + 'req_id'),
+                                                _("Certificates"), self)
             return 1
         fc = open(cert_path + 'req_id', 'r')
         req_id = fc.read()
