@@ -1,7 +1,6 @@
-#!/usr/bin/python
 #-*- coding: utf-8 -*-
 
-# Copyright 2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -327,7 +326,10 @@ class MainFrameRes(QtGui.QWidget):
 
     def endTask(self, item, set_res = True):
         if set_res:
-            self.set_result_task()
+            if hasattr(item,"result") and not item.result is None:
+                self.set_result_task(not item.result)
+            else:
+                self.set_result_task()
         message = item.message if item.message else ''
         if message:
             lbl_temp = LabelWordWrap(message, self)
@@ -388,9 +390,6 @@ class MainFrameRes(QtGui.QWidget):
     def endGroup(self, item):
         pass
 
-    def callView(self, item, sid):
-        return 0
-
     def kill_process(self, pid):
         def wrapper():
             sid = int(self.ClientObj.sid)
@@ -511,8 +510,6 @@ class MainFrameRes(QtGui.QWidget):
             if case('endGroup'):
                 self.endGroup(item)
                 return 1
-            if case('briefParams'):
-                self.callView(item, sid)
             if case(): # default, could also just omit condition or 'if True'
                 return 1
 
@@ -534,7 +531,7 @@ class MainFrameRes(QtGui.QWidget):
                 if self.get_Frame_thread.isRunning():
                     self.get_Frame_thread.wait()
             self.get_Frame_thread = ClientServiceThread(self.ClientObj,\
-                           'get_frame', sid, pid, return_except = True, \
+                           'get_frame', sid, pid, "gui",  return_except = True, \
                            through_object = (sid, pid))
             self.get_Frame_thread.signal_extended.connect(self.get_Frame_cycle)
             self.get_Frame_thread.start()
@@ -542,9 +539,8 @@ class MainFrameRes(QtGui.QWidget):
     def get_Frame_cycle(self, current_frame, through_object):
         if type(current_frame) == Exception:
             _print (_("Failed to get a frame from the server."))
-            show_msg(_("Failed to get a frame from the server.") +'\n'+ \
-                     _('Try resfeshing this page later.'),'get frame error')
-            return 1
+            #show_msg(_("Failed to get a frame from the server.") +'\n'+ \
+            #         _('Try resfeshing this page later.'),'get frame error')
         sid, pid = through_object
         if current_frame in [None, [], ""]:
             try:
@@ -552,23 +548,27 @@ class MainFrameRes(QtGui.QWidget):
                     return 1
             except:
                 return 1
-        else:
+        elif not isinstance(current_frame,Exception):
             self.get_Frame_after(current_frame, sid, pid)
         if self.not_end_frame:
             # Call server method
             if hasattr (self, 'get_Frame_thread'):
                 if self.get_Frame_thread.isRunning():
                     self.get_Frame_thread.wait()
-            self.get_Frame_thread = ClientServiceThread(self.ClientObj,\
-                          'get_frame', sid, pid, return_except = True, \
-                          sleeptime = 0, #int(self.ClientObj.client.frame_period),\
+            if self.ClientObj.host_name in ('localhost','127.0.0.1'):
+                sleeptime = 0
+            else:
+                sleeptime = int(self.ClientObj.client.frame_period)
+            self.get_Frame_thread = ClientServiceThread(self.ClientObj,
+                          'get_frame', sid, pid, "gui",return_except = True,
+                          sleeptime = sleeptime,
                           through_object = (sid, pid))
             self.get_Frame_thread.signal_extended.connect(self.get_Frame_cycle)
             self.get_Frame_thread.start()
 
     def get_Frame_after(self, current_frame, sid, pid):
             for item in range(len(current_frame[0])):
-                self.not_end_frame = self.get_message(current_frame[0][item], \
+                self.not_end_frame = self.get_message(current_frame[0][item],
                                                                     sid, pid)
                 try:
                     if  self.cur_pid != pid:
@@ -664,13 +664,26 @@ class MainFrameRes(QtGui.QWidget):
         self.get_Progress_thread.start()
 
     def get_Progress_cycle(self, returnProgr, through_object):
+        sid, pid, id, temp_progress, progressBar = through_object
+        def nextProgress():
+            if hasattr (self, 'get_Progress_thread'):
+                if self.get_Progress_thread.isRunning():
+                    self.get_Progress_thread.wait()
+            self.get_Progress_thread = ClientServiceThread(self.ClientObj,\
+                           'get_progress', sid, pid, id, return_except = True,\
+                           sleeptime = 1, through_object = \
+                           (sid, pid, id, temp_progress, progressBar))
+            self.get_Progress_thread.signal_extended.connect \
+                                                    (self.get_Progress_cycle)
+            self.get_Progress_thread.start()
+
         if type(returnProgr) == Exception:
             _print (_('Failed to get the progress status from the server'))
 #            show_msg(_('Failed to get the progress status from the server') + \
 #                    '\n'+ \
 #                   _('Try resfeshing this page later.'),'get progress error')
+            nextProgress()
             return 1
-        sid, pid, id, temp_progress, progressBar = through_object
 ########################################
         try:
             percent = returnProgr.percent
@@ -696,17 +709,7 @@ class MainFrameRes(QtGui.QWidget):
                 return 1
 
             # Call server method
-            if hasattr (self, 'get_Progress_thread'):
-                if self.get_Progress_thread.isRunning():
-                    self.get_Progress_thread.wait()
-            self.get_Progress_thread = ClientServiceThread(self.ClientObj,\
-                           'get_progress', sid, pid, id, return_except = True,\
-                           sleeptime = 1, through_object = \
-                           (sid, pid, id, temp_progress, progressBar))
-            self.get_Progress_thread.signal_extended.connect \
-                                                    (self.get_Progress_cycle)
-            self.get_Progress_thread.start()
-
+            nextProgress()
         if percent < 0:
             progressBar.setMaximum(100)
             returnProgr.percent = 0 - percent
